Geometry Module
=================

.. automodule:: geometry
   :members:
   
   .. autosummary::
      
      find_closest_plane
      fit_plane_svd
      get_a_polygon_from_plane_equation_and_point
      get_angle_between_lines
      get_angle_between_vectors
      get_best_plane_from_points_from_two_segments
      get_centroid_of_points
      get_distance_from_point_to_plane
      get_distance_from_points_to_plane
      get_intersection_point_of_line_with_plane
      get_intersection_points_of_line_with_cube
      get_limits_of_3d_graph_from_limits_of_object
      get_limits_of_graph_from_limits_of_object
      get_parallelepiped_3d_vertices
      get_parallelogram_2d_vertices
      get_parallelogram_3d_vertices
      get_plane_equation
      get_plane_from_list_of_three_points
      get_point_of_plane_closest_to_given_point
      get_two_perpendicular_unit_vectors_in_plane
